"use strict";
/*
 * ATTENTION: The "eval" devtool has been used (maybe by default in mode: "development").
 * This devtool is neither made for production nor for readable output files.
 * It uses "eval()" calls to create a separate source file in the browser devtools.
 * If you are trying to read the output file, select a different devtool (https://webpack.js.org/configuration/devtool/)
 * or disable the default devtool with "devtool: false".
 * If you are looking for production-ready output files, see mode: "production" (https://webpack.js.org/configuration/mode/).
 */
(self["webpackChunkfrontend"] = self["webpackChunkfrontend"] || []).push([["src_nodes_BaseNode_tsx"],{

/***/ "./src/backend.ts":
/*!************************!*\
  !*** ./src/backend.ts ***!
  \************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"nullValue\": () => (/* binding */ nullValue)\n/* harmony export */ });\n// Generated using py-ts-interfaces.\n// See https://github.com/cs-cordero/py-ts-interfaces\n\nconst nullValue = \"SPECIALNULLVALUEDONOTSETEVER\";\n\n//# sourceURL=webpack://frontend/./src/backend.ts?");

/***/ }),

/***/ "./src/nodes/BaseNode.tsx":
/*!********************************!*\
  !*** ./src/nodes/BaseNode.tsx ***!
  \********************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var styled_components__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(/*! styled-components */ \"./node_modules/.pnpm/styled-components@5.3.10_7i5myeigehqah43i5u7wbekgba/node_modules/styled-components/dist/styled-components.browser.esm.js\");\n/* harmony import */ var antd__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! antd */ \"./node_modules/.pnpm/antd@5.4.7_biqbaboplfbrettd7655fr4n2y/node_modules/antd/es/tooltip/index.js\");\n/* harmony import */ var antd__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(/*! antd */ \"./node_modules/.pnpm/antd@5.4.7_biqbaboplfbrettd7655fr4n2y/node_modules/antd/es/switch/index.js\");\n/* harmony import */ var antd__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(/*! antd */ \"./node_modules/.pnpm/antd@5.4.7_biqbaboplfbrettd7655fr4n2y/node_modules/antd/es/typography/index.js\");\n/* harmony import */ var antd__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(/*! antd */ \"./node_modules/.pnpm/antd@5.4.7_biqbaboplfbrettd7655fr4n2y/node_modules/antd/es/segmented/index.js\");\n/* harmony import */ var antd__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(/*! antd */ \"./node_modules/.pnpm/antd@5.4.7_biqbaboplfbrettd7655fr4n2y/node_modules/antd/es/select/index.js\");\n/* harmony import */ var antd__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(/*! antd */ \"./node_modules/.pnpm/antd@5.4.7_biqbaboplfbrettd7655fr4n2y/node_modules/antd/es/input-number/index.js\");\n/* harmony import */ var antd__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(/*! antd */ \"./node_modules/.pnpm/antd@5.4.7_biqbaboplfbrettd7655fr4n2y/node_modules/antd/es/input/index.js\");\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! react */ \"webpack/sharing/consume/default/react/react\");\n/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var zod__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! zod */ \"./node_modules/.pnpm/zod@3.21.4/node_modules/zod/lib/index.mjs\");\n/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../util */ \"./src/util.ts\");\n/* harmony import */ var _ant_design_icons__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(/*! @ant-design/icons */ \"./node_modules/.pnpm/@ant-design+icons@5.0.1_biqbaboplfbrettd7655fr4n2y/node_modules/@ant-design/icons/es/icons/LoginOutlined.js\");\n/* harmony import */ var _ant_design_icons__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(/*! @ant-design/icons */ \"./node_modules/.pnpm/@ant-design+icons@5.0.1_biqbaboplfbrettd7655fr4n2y/node_modules/@ant-design/icons/es/icons/PlayCircleOutlined.js\");\n/* harmony import */ var _ant_design_icons__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(/*! @ant-design/icons */ \"./node_modules/.pnpm/@ant-design+icons@5.0.1_biqbaboplfbrettd7655fr4n2y/node_modules/@ant-design/icons/es/icons/PicCenterOutlined.js\");\n/* harmony import */ var _style_css__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! ./style.css */ \"./src/nodes/style.css\");\n/* harmony import */ var antd_dist_reset_css__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! antd/dist/reset.css */ \"./node_modules/.pnpm/antd@5.4.7_biqbaboplfbrettd7655fr4n2y/node_modules/antd/dist/reset.css\");\n/* harmony import */ var _backend__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! ../backend */ \"./src/backend.ts\");\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\nconst dataSchema = zod__WEBPACK_IMPORTED_MODULE_5__.z.array(zod__WEBPACK_IMPORTED_MODULE_5__.z.any());\nfunction RenderArgument({\n  arg,\n  callUpdate,\n  argValue: fullValue,\n  setArg: setFullValue,\n  setNode,\n  idx: key,\n  optional = false\n}) {\n  const ref = (0,react__WEBPACK_IMPORTED_MODULE_0__.useRef)(null);\n  const mode = fullValue ? fullValue[\"mode\"] : arg.type === \"File\" ? \"input\" : \"node\";\n  const argValue = fullValue ? fullValue[\"value\"] : fullValue;\n  const setArg = newArg => {\n    if (setFullValue) setFullValue({\n      mode,\n      value: newArg\n    });\n  };\n  const setMode = newMode => {\n    if (setFullValue) setFullValue({\n      mode: newMode,\n      value: argValue\n    });\n  };\n  const setBoth = (newMode, newArg) => {\n    if (setFullValue) setFullValue({\n      mode: newMode,\n      value: newArg\n    });\n  };\n  (0,react__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {\n    if (!fullValue && (mode == \"input\" || optional) && setFullValue) {\n      setArg(_backend__WEBPACK_IMPORTED_MODULE_4__.nullValue);\n    }\n  }, [fullValue, optional, mode, setFullValue]);\n  (0,react__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {\n    if (mode === \"input\" && ref.current && ref.current.offsetTop && ref.current.clientHeight) {\n      console.log(\"OFFSET\");\n      setNode(nd => {\n        const newInputHandles = {\n          ...(nd.input_handles ? nd.input_handles : {}),\n          [key]: (ref.current?.offsetTop ?? 0) - 28\n        };\n        return {\n          ...nd,\n          input_handles: newInputHandles,\n          num_inputs: Object.keys(newInputHandles).length\n        };\n      });\n      callUpdate();\n    }\n  }, [mode, ref]);\n  (0,react__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {\n    if (mode === \"node\") {\n      setNode(nd => {\n        const newInputHandles = {\n          ...(nd.input_handles ? nd.input_handles : {})\n        };\n        if (newInputHandles[key]) delete newInputHandles[key];\n        return {\n          ...nd,\n          num_inputs: Object.keys(newInputHandles).length,\n          input_handles: newInputHandles\n        };\n      });\n      callUpdate();\n    }\n  }, [mode]);\n  return arg.type === \"Option\" ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(RenderArgument, {\n    arg: {\n      name: arg.name,\n      ty: arg.ty.inner,\n      type: arg.ty._type\n    },\n    callUpdate: callUpdate,\n    argValue: fullValue,\n    setArg: setFullValue,\n    setNode: setNode,\n    idx: key,\n    optional: true\n  }) : /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(\"div\", {\n    className: \"flex flex-row space-x-2 items-center w-full\",\n    ref: ref\n  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_StyledSegmented, {\n    className: \"nodrag\",\n    onClick: e => {\n      e.stopPropagation();\n    },\n    size: \"small\",\n    value: mode,\n    onChange: newMode => {\n      if (newMode === \"node\") setMode(newMode.toString());else setBoth(newMode.toString(), _backend__WEBPACK_IMPORTED_MODULE_4__.nullValue);\n    },\n    options: [{\n      label: /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(antd__WEBPACK_IMPORTED_MODULE_6__[\"default\"], {\n        title: \"External Input\"\n      }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_StyledLoginOutlined, null)),\n      value: \"input\"\n    }, {\n      label: /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(antd__WEBPACK_IMPORTED_MODULE_6__[\"default\"], {\n        title: \"UI Popup\"\n      }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_StyledPlayCircleOutlined, null)),\n      value: \"ui\",\n      disabled: true\n    }, {\n      label: /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(antd__WEBPACK_IMPORTED_MODULE_6__[\"default\"], {\n        title: \"Hardcode\"\n      }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_StyledPicCenterOutlined, null)),\n      value: \"node\",\n      disabled: arg.type === \"File\"\n    }]\n  }), /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_StyledTypographyText, null, arg.name, !optional ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(\"span\", {\n    style: {\n      color: \"red\"\n    }\n  }, \"*\") : null), (() => {\n    switch (arg.type) {\n      case \"Choice\":\n        return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_StyledSelect, {\n          className: \"nodrag\",\n          disabled: mode !== \"node\",\n          value: argValue && argValue != _backend__WEBPACK_IMPORTED_MODULE_4__.nullValue ? argValue : undefined,\n          options: arg.ty.choices.map(x => ({\n            value: x,\n            label: x\n          })),\n          onChange: newArg => {\n            setArg(newArg);\n          }\n        });\n      case \"Num\":\n        return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_StyledInputNumber, {\n          className: \"nodrag\",\n          disabled: mode !== \"node\",\n          min: arg.ty.min_value ?? undefined,\n          max: arg.ty.max_value ?? undefined,\n          value: argValue && argValue != _backend__WEBPACK_IMPORTED_MODULE_4__.nullValue ? argValue : undefined,\n          onChange: newArg => {\n            if (newArg) setArg(newArg);\n          }\n        });\n      case \"String\":\n        {\n          return arg.ty.secret ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_StyledInputPassword, {\n            className: \"nodrag\",\n            disabled: mode !== \"node\",\n            value: argValue && argValue != _backend__WEBPACK_IMPORTED_MODULE_4__.nullValue ? argValue : undefined,\n            onChange: e => {\n              setArg(e.target.value);\n            }\n          }) : /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_StyledInput, {\n            className: \"nodrag\",\n            disabled: mode !== \"node\",\n            value: argValue && argValue != _backend__WEBPACK_IMPORTED_MODULE_4__.nullValue ? argValue : undefined,\n            onChange: e => {\n              setArg(e.target.value);\n            }\n          });\n        }\n      case \"Json\":\n        {\n          return null;\n        }\n      case \"Bool\":\n        return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(antd__WEBPACK_IMPORTED_MODULE_7__[\"default\"], {\n          disabled: mode !== \"node\",\n          onChange: newArg => {\n            setArg(newArg);\n          },\n          checked: argValue && argValue != _backend__WEBPACK_IMPORTED_MODULE_4__.nullValue ? argValue : arg.ty.default\n        });\n      case \"File\":\n        return null;\n      case \"Dir\":\n        return null;\n      case \"Func\":\n        return null;\n      case \"Funcs\":\n        return null;\n      default:\n        {\n          const exhaustiveCheck = arg.type;\n          throw new Error(\"Unhandled argument type\");\n        }\n    }\n  })());\n}\nfunction BaseNode({\n  callAfterUpdateInpOuts = () => {},\n  node,\n  setNode\n}) {\n  const data = dataSchema.safeParse(node.data).success ? node.data : Array(node.metadata.args.length).fill(null);\n  const initialized = dataSchema.length(node.metadata.args.length).safeParse(node.data).success;\n  (0,react__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {\n    if (!initialized) {\n      setNode(nd => ({\n        ...nd,\n        data: Array(node.metadata.args.length).fill(null),\n        operator: node.metadata.lambda ? `${node.metadata.lambda}/operator/${node.metadata.operator}` : `${(0,_util__WEBPACK_IMPORTED_MODULE_1__.baseUrl)(node.remote.url)}/operator/${node.metadata.operator}`,\n        num_inputs: 0,\n        num_outputs: node.metadata.num_outputs\n      }));\n      callAfterUpdateInpOuts();\n    }\n  }, [node]);\n  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_StyledDiv, null, node.metadata.name ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(_StyledTypographyText2, null, node.metadata.name) : null, node.metadata.description ? /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(antd__WEBPACK_IMPORTED_MODULE_8__[\"default\"].Paragraph, null, node.metadata.description) : null, node.metadata.args.map((arg, idx) => /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(RenderArgument, {\n    arg: arg,\n    key: idx,\n    idx: idx,\n    callUpdate: callAfterUpdateInpOuts,\n    argValue: data[idx],\n    setNode: setNode,\n    setArg: initialized ? newArg => {\n      setNode(nd => ({\n        ...nd,\n        data: nd.data.map((x, i) => i === idx ? newArg : x)\n      }));\n    } : undefined\n  })));\n}\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (BaseNode);\nvar _StyledSegmented = (0,styled_components__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(antd__WEBPACK_IMPORTED_MODULE_10__[\"default\"]).withConfig({\n  displayName: \"BaseNode___StyledSegmented\",\n  componentId: \"sc-vkkiaj-0\"\n})({\n  \"pointerEvents\": \"auto\",\n  \"cursor\": \"pointer\"\n});\nvar _StyledLoginOutlined = (0,styled_components__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(_ant_design_icons__WEBPACK_IMPORTED_MODULE_11__[\"default\"]).withConfig({\n  displayName: \"BaseNode___StyledLoginOutlined\",\n  componentId: \"sc-vkkiaj-1\"\n})({\n  \"paddingTop\": \"3px\"\n});\nvar _StyledPlayCircleOutlined = (0,styled_components__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(_ant_design_icons__WEBPACK_IMPORTED_MODULE_12__[\"default\"]).withConfig({\n  displayName: \"BaseNode___StyledPlayCircleOutlined\",\n  componentId: \"sc-vkkiaj-2\"\n})({\n  \"paddingTop\": \"3px\"\n});\nvar _StyledPicCenterOutlined = (0,styled_components__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(_ant_design_icons__WEBPACK_IMPORTED_MODULE_13__[\"default\"]).withConfig({\n  displayName: \"BaseNode___StyledPicCenterOutlined\",\n  componentId: \"sc-vkkiaj-3\"\n})({\n  \"paddingTop\": \"3px\"\n});\nvar _StyledTypographyText = (0,styled_components__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(antd__WEBPACK_IMPORTED_MODULE_8__[\"default\"].Text).withConfig({\n  displayName: \"BaseNode___StyledTypographyText\",\n  componentId: \"sc-vkkiaj-4\"\n})({\n  \"width\": \"fit-content\",\n  \"whiteSpace\": \"nowrap\"\n});\nvar _StyledSelect = (0,styled_components__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(antd__WEBPACK_IMPORTED_MODULE_14__[\"default\"]).withConfig({\n  displayName: \"BaseNode___StyledSelect\",\n  componentId: \"sc-vkkiaj-5\"\n})({\n  \"flexGrow\": \"1\"\n});\nvar _StyledInputNumber = (0,styled_components__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(antd__WEBPACK_IMPORTED_MODULE_15__[\"default\"]).withConfig({\n  displayName: \"BaseNode___StyledInputNumber\",\n  componentId: \"sc-vkkiaj-6\"\n})({\n  \"flexGrow\": \"1\"\n});\nvar _StyledInputPassword = (0,styled_components__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(antd__WEBPACK_IMPORTED_MODULE_16__[\"default\"].Password).withConfig({\n  displayName: \"BaseNode___StyledInputPassword\",\n  componentId: \"sc-vkkiaj-7\"\n})({\n  \"flexGrow\": \"1\"\n});\nvar _StyledInput = (0,styled_components__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(antd__WEBPACK_IMPORTED_MODULE_16__[\"default\"]).withConfig({\n  displayName: \"BaseNode___StyledInput\",\n  componentId: \"sc-vkkiaj-8\"\n})({\n  \"flexGrow\": \"1\"\n});\nvar _StyledDiv = (0,styled_components__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(\"div\").withConfig({\n  displayName: \"BaseNode___StyledDiv\",\n  componentId: \"sc-vkkiaj-9\"\n})({\n  \"display\": \"flex\",\n  \"width\": \"24rem\",\n  \"flexDirection\": \"column\",\n  \"> :not([hidden]) ~ :not([hidden])\": {\n    \"--tw-space-y-reverse\": \"0\",\n    \"marginTop\": \"calc(0.5rem * calc(1 - var(--tw-space-y-reverse)))\",\n    \"marginBottom\": \"calc(0.5rem * var(--tw-space-y-reverse))\"\n  }\n});\nvar _StyledTypographyText2 = (0,styled_components__WEBPACK_IMPORTED_MODULE_9__[\"default\"])(antd__WEBPACK_IMPORTED_MODULE_8__[\"default\"].Text).withConfig({\n  displayName: \"BaseNode___StyledTypographyText2\",\n  componentId: \"sc-vkkiaj-10\"\n})({\n  \"fontWeight\": \"700\"\n});\n\n//# sourceURL=webpack://frontend/./src/nodes/BaseNode.tsx?");

/***/ }),

/***/ "./src/util.ts":
/*!*********************!*\
  !*** ./src/util.ts ***!
  \*********************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"baseUrl\": () => (/* binding */ baseUrl)\n/* harmony export */ });\nfunction baseUrl(url) {\n  const pathArray = url.split(\"/\");\n  const protocol = pathArray[0];\n  const host = pathArray[2];\n  return protocol + \"//\" + host;\n}\n\n//# sourceURL=webpack://frontend/./src/util.ts?");

/***/ }),

/***/ "./node_modules/.pnpm/css-loader@6.7.3_webpack@5.82.0/node_modules/css-loader/dist/cjs.js!./src/nodes/style.css":
/*!**********************************************************************************************************************!*\
  !*** ./node_modules/.pnpm/css-loader@6.7.3_webpack@5.82.0/node_modules/css-loader/dist/cjs.js!./src/nodes/style.css ***!
  \**********************************************************************************************************************/
/***/ ((module, __webpack_exports__, __webpack_require__) => {

eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _node_modules_pnpm_css_loader_6_7_3_webpack_5_82_0_node_modules_css_loader_dist_runtime_noSourceMaps_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! ../../node_modules/.pnpm/css-loader@6.7.3_webpack@5.82.0/node_modules/css-loader/dist/runtime/noSourceMaps.js */ \"./node_modules/.pnpm/css-loader@6.7.3_webpack@5.82.0/node_modules/css-loader/dist/runtime/noSourceMaps.js\");\n/* harmony import */ var _node_modules_pnpm_css_loader_6_7_3_webpack_5_82_0_node_modules_css_loader_dist_runtime_noSourceMaps_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_pnpm_css_loader_6_7_3_webpack_5_82_0_node_modules_css_loader_dist_runtime_noSourceMaps_js__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var _node_modules_pnpm_css_loader_6_7_3_webpack_5_82_0_node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! ../../node_modules/.pnpm/css-loader@6.7.3_webpack@5.82.0/node_modules/css-loader/dist/runtime/api.js */ \"./node_modules/.pnpm/css-loader@6.7.3_webpack@5.82.0/node_modules/css-loader/dist/runtime/api.js\");\n/* harmony import */ var _node_modules_pnpm_css_loader_6_7_3_webpack_5_82_0_node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_node_modules_pnpm_css_loader_6_7_3_webpack_5_82_0_node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1__);\n// Imports\n\n\nvar ___CSS_LOADER_EXPORT___ = _node_modules_pnpm_css_loader_6_7_3_webpack_5_82_0_node_modules_css_loader_dist_runtime_api_js__WEBPACK_IMPORTED_MODULE_1___default()((_node_modules_pnpm_css_loader_6_7_3_webpack_5_82_0_node_modules_css_loader_dist_runtime_noSourceMaps_js__WEBPACK_IMPORTED_MODULE_0___default()));\n// Module\n___CSS_LOADER_EXPORT___.push([module.id, \"svg {\\n  display: inline-block !important;\\n  vertical-align: baseline !important;\\n}\\n\", \"\"]);\n// Exports\n/* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (___CSS_LOADER_EXPORT___);\n\n\n//# sourceURL=webpack://frontend/./src/nodes/style.css?./node_modules/.pnpm/css-loader@6.7.3_webpack@5.82.0/node_modules/css-loader/dist/cjs.js");

/***/ }),

/***/ "./src/nodes/style.css":
/*!*****************************!*\
  !*** ./src/nodes/style.css ***!
  \*****************************/
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

eval("__webpack_require__.r(__webpack_exports__);\n/* harmony export */ __webpack_require__.d(__webpack_exports__, {\n/* harmony export */   \"default\": () => (__WEBPACK_DEFAULT_EXPORT__)\n/* harmony export */ });\n/* harmony import */ var _node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(/*! !../../node_modules/.pnpm/style-loader@3.3.2_webpack@5.82.0/node_modules/style-loader/dist/runtime/injectStylesIntoStyleTag.js */ \"./node_modules/.pnpm/style-loader@3.3.2_webpack@5.82.0/node_modules/style-loader/dist/runtime/injectStylesIntoStyleTag.js\");\n/* harmony import */ var _node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0__);\n/* harmony import */ var _node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_styleDomAPI_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(/*! !../../node_modules/.pnpm/style-loader@3.3.2_webpack@5.82.0/node_modules/style-loader/dist/runtime/styleDomAPI.js */ \"./node_modules/.pnpm/style-loader@3.3.2_webpack@5.82.0/node_modules/style-loader/dist/runtime/styleDomAPI.js\");\n/* harmony import */ var _node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_styleDomAPI_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_styleDomAPI_js__WEBPACK_IMPORTED_MODULE_1__);\n/* harmony import */ var _node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_insertBySelector_js__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(/*! !../../node_modules/.pnpm/style-loader@3.3.2_webpack@5.82.0/node_modules/style-loader/dist/runtime/insertBySelector.js */ \"./node_modules/.pnpm/style-loader@3.3.2_webpack@5.82.0/node_modules/style-loader/dist/runtime/insertBySelector.js\");\n/* harmony import */ var _node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_insertBySelector_js__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_insertBySelector_js__WEBPACK_IMPORTED_MODULE_2__);\n/* harmony import */ var _node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_setAttributesWithoutAttributes_js__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(/*! !../../node_modules/.pnpm/style-loader@3.3.2_webpack@5.82.0/node_modules/style-loader/dist/runtime/setAttributesWithoutAttributes.js */ \"./node_modules/.pnpm/style-loader@3.3.2_webpack@5.82.0/node_modules/style-loader/dist/runtime/setAttributesWithoutAttributes.js\");\n/* harmony import */ var _node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_setAttributesWithoutAttributes_js__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(_node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_setAttributesWithoutAttributes_js__WEBPACK_IMPORTED_MODULE_3__);\n/* harmony import */ var _node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_insertStyleElement_js__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(/*! !../../node_modules/.pnpm/style-loader@3.3.2_webpack@5.82.0/node_modules/style-loader/dist/runtime/insertStyleElement.js */ \"./node_modules/.pnpm/style-loader@3.3.2_webpack@5.82.0/node_modules/style-loader/dist/runtime/insertStyleElement.js\");\n/* harmony import */ var _node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_insertStyleElement_js__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(_node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_insertStyleElement_js__WEBPACK_IMPORTED_MODULE_4__);\n/* harmony import */ var _node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_styleTagTransform_js__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(/*! !../../node_modules/.pnpm/style-loader@3.3.2_webpack@5.82.0/node_modules/style-loader/dist/runtime/styleTagTransform.js */ \"./node_modules/.pnpm/style-loader@3.3.2_webpack@5.82.0/node_modules/style-loader/dist/runtime/styleTagTransform.js\");\n/* harmony import */ var _node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_styleTagTransform_js__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(_node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_styleTagTransform_js__WEBPACK_IMPORTED_MODULE_5__);\n/* harmony import */ var _node_modules_pnpm_css_loader_6_7_3_webpack_5_82_0_node_modules_css_loader_dist_cjs_js_style_css__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(/*! !!../../node_modules/.pnpm/css-loader@6.7.3_webpack@5.82.0/node_modules/css-loader/dist/cjs.js!./style.css */ \"./node_modules/.pnpm/css-loader@6.7.3_webpack@5.82.0/node_modules/css-loader/dist/cjs.js!./src/nodes/style.css\");\n\n      \n      \n      \n      \n      \n      \n      \n      \n      \n\nvar options = {};\n\noptions.styleTagTransform = (_node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_styleTagTransform_js__WEBPACK_IMPORTED_MODULE_5___default());\noptions.setAttributes = (_node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_setAttributesWithoutAttributes_js__WEBPACK_IMPORTED_MODULE_3___default());\n\n      options.insert = _node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_insertBySelector_js__WEBPACK_IMPORTED_MODULE_2___default().bind(null, \"head\");\n    \noptions.domAPI = (_node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_styleDomAPI_js__WEBPACK_IMPORTED_MODULE_1___default());\noptions.insertStyleElement = (_node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_insertStyleElement_js__WEBPACK_IMPORTED_MODULE_4___default());\n\nvar update = _node_modules_pnpm_style_loader_3_3_2_webpack_5_82_0_node_modules_style_loader_dist_runtime_injectStylesIntoStyleTag_js__WEBPACK_IMPORTED_MODULE_0___default()(_node_modules_pnpm_css_loader_6_7_3_webpack_5_82_0_node_modules_css_loader_dist_cjs_js_style_css__WEBPACK_IMPORTED_MODULE_6__[\"default\"], options);\n\n\n\n\n       /* harmony default export */ const __WEBPACK_DEFAULT_EXPORT__ = (_node_modules_pnpm_css_loader_6_7_3_webpack_5_82_0_node_modules_css_loader_dist_cjs_js_style_css__WEBPACK_IMPORTED_MODULE_6__[\"default\"] && _node_modules_pnpm_css_loader_6_7_3_webpack_5_82_0_node_modules_css_loader_dist_cjs_js_style_css__WEBPACK_IMPORTED_MODULE_6__[\"default\"].locals ? _node_modules_pnpm_css_loader_6_7_3_webpack_5_82_0_node_modules_css_loader_dist_cjs_js_style_css__WEBPACK_IMPORTED_MODULE_6__[\"default\"].locals : undefined);\n\n\n//# sourceURL=webpack://frontend/./src/nodes/style.css?");

/***/ })

}]);